# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-06-22 10:50
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('articles', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='article',
            options={'get_latest_by': 'created_at', 'permissions': (('view_article', 'Can view article'),)},
        ),
    ]
